import pytest

from aurweb import db
from aurweb.models import PackageBase, User
from aurweb.time import utcnow


@pytest.fixture(autouse=True)
def setup(db_test: None) -> None:
    pass


@pytest.fixture
def user() -> User:

    with db.begin():
        user_ = db.create(User, Username="test", Email="test@example.org")

    yield user_


@pytest.fixture
def pkgbase(user: User) -> PackageBase:
    now = utcnow()

    with db.begin():
        pkgbase_ = db.create(
            PackageBase,
            Name="pkg",
            ModifiedTS=now,
            MetaModifiedTS=now,
            SubmittedTS=now,
            Maintainer=user,
            Packager=user,
        )

    yield pkgbase_


def test_package_base_columns(user: User, pkgbase: PackageBase):
    assert pkgbase.Name == "pkg"

    assert bool(pkgbase.SubmittedTS)
    assert bool(pkgbase.ModifiedTS)
    assert bool(pkgbase.MetaModifiedTS)

    assert pkgbase.Maintainer == user
    assert pkgbase.Packager == user
    assert pkgbase.Flagger is None
